@@ -18,10 +18,12 @@ from botocore.client import ClientMeta
 
 from mypy_boto3_compute_optimizer.type_defs import (
     DescribeRecommendationExportJobsResponseTypeDef,
+    EBSFilterTypeDef,
     ExportAutoScalingGroupRecommendationsResponseTypeDef,
     ExportEC2InstanceRecommendationsResponseTypeDef,
     FilterTypeDef,
     GetAutoScalingGroupRecommendationsResponseTypeDef,
+    GetEBSVolumeRecommendationsResponseTypeDef,
     GetEC2InstanceRecommendationsResponseTypeDef,
     GetEC2RecommendationProjectedMetricsResponseTypeDef,
     GetEnrollmentStatusResponseTypeDef,
@@ -63,7 +65,7 @@ class Exceptions:
 
 class ComputeOptimizerClient:
     """
-    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     """
 
     meta: ClientMeta
@@ -71,7 +73,7 @@ class ComputeOptimizerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         """
 
     def describe_recommendation_export_jobs(
@@ -82,7 +84,7 @@ class ComputeOptimizerClient:
         maxResults: int = None,
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
-        [Client.describe_recommendation_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Client.describe_recommendation_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         """
 
     def export_auto_scaling_group_recommendations(
@@ -135,7 +137,7 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Client.export_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Client.export_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         """
 
     def export_ec2_instance_recommendations(
@@ -184,7 +186,7 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Client.export_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Client.export_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         """
 
     def generate_presigned_url(
@@ -195,7 +197,7 @@ class ComputeOptimizerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
@@ -207,7 +209,19 @@ class ComputeOptimizerClient:
         filters: List[FilterTypeDef] = None,
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        """
+
+    def get_ebs_volume_recommendations(
+        self,
+        volumeArns: List[str] = None,
+        nextToken: str = None,
+        maxResults: int = None,
+        filters: List[EBSFilterTypeDef] = None,
+        accountIds: List[str] = None,
+    ) -> GetEBSVolumeRecommendationsResponseTypeDef:
+        """
+        [Client.get_ebs_volume_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
         """
 
     def get_ec2_instance_recommendations(
@@ -219,7 +233,7 @@ class ComputeOptimizerClient:
         accountIds: List[str] = None,
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         """
 
     def get_ec2_recommendation_projected_metrics(
@@ -231,19 +245,19 @@ class ComputeOptimizerClient:
         endTime: datetime,
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
-        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         """
 
     def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
-        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         """
 
     def get_recommendation_summaries(
         self, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
-        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         """
 
     def update_enrollment_status(
@@ -252,5 +266,5 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
-        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         """
